@@ -211,7 +211,7 @@ class AppContext(NamespaceMixin, ResponseMixin, ExecuteMixin):
 
     def req_equals(self, name):
         try:
-            if self.request.field_value(name): 
+            if self.request.field_value(name):
                 return 1
         except KeyError:
             try:
@@ -397,11 +397,9 @@ class PageModuleMixin:
 
     def load_page(self, ctx):
         if ctx.locals.__page__:
-            name = ctx.locals.__page__
+            self.load_page_module(ctx, ctx.locals.__page__)
         else:
-            name = self.__start_page
-            ctx.set_page(name)
-        self.load_page_module(ctx, name)
+            ctx.set_page(self.start_page())     # recursively calls load_page
 
     def is_page_module(self, name):
         return name.startswith(self.mod_holder_name)
@@ -489,11 +487,9 @@ class PageObjectMixin:
 
     def load_page(self, ctx):
         if ctx.locals.__page__:
-            name = ctx.locals.__page__
+            ctx.page = ctx.locals.__page__
         else:
-            name = self.__start_page
-            ctx.set_page(name)
-        ctx.page = name
+            ctx.set_page(self.start_page())     # recursively calls load_page
 
     def page_enter(self, ctx, args):
         obj = self.__page_objects[ctx.page]
