@@ -20,7 +20,7 @@ except ImportError:
 import base64
 import md5
 
-from albatross.template import Template
+from albatross.template import Template, check_tagname
 from albatross.common import *
 
 # old cPickle used string exceptions, and therefore couldn't subclass a common
@@ -106,6 +106,7 @@ class ResourceMixin:
 
     def register_tagclasses(self, *tags):
         for tag in tags:
+            check_tagname(tag.name)
             self.__tags[tag.name] = tag
 
 # ------------------------------------------------------------------
