@@ -32,17 +32,17 @@ class SessionCookieMixin:
                 pass
         return None
 
-    def _set_sesid_cookie(self, sesid, age):
+    def _set_sesid_cookie(self, sesid):
         c = Cookie.SimpleCookie()
         appid = self.app.ses_appid()
-        c[appid] = sesid
+        if sesid is None:
+            c[appid] = ''
+        else:
+            c[appid] = sesid
         path = self.absolute_base_url()
         c[appid]['path'] = path
         if self.parsed_request_uri()[0] == 'https':
             c[appid]['secure'] = True
-        ses_age = self.app.ses_age()
-        if age is not None:
-            c[appid]['max-age'] = age
         prefix_len = len('Set-Cookie: ')
         self.set_header('Set-Cookie', str(c)[prefix_len:])
 
@@ -61,9 +61,10 @@ class SessionServerContextMixin(SessionCookieMixin, SessionBase):
         text = None
         if sesid:
             text = self.app.get_session(sesid)
-        if not text:
-            if self.request.get_method().upper() != 'GET':
+            if not text:
+                self._set_sesid_cookie(None)
                 raise SessionExpired('Session expired or browser does not support cookies')
+        else:
             sesid = self.app.new_session()
         self.__sesid = sesid
         if text:
@@ -75,7 +76,11 @@ class SessionServerContextMixin(SessionCookieMixin, SessionBase):
             except:
                 self.app.del_session(sesid)
                 raise
-        self._set_sesid_cookie(self.__sesid, self.app.ses_age())
+        self._set_sesid_cookie(self.__sesid)
+
+    def new_session(self):
+        self.__sesid = self.app.new_session()
+        self._set_sesid_cookie(self.__sesid)
 
     def save_session(self):
         if self.should_save_session() and self.__sesid is not None:
@@ -89,9 +94,8 @@ class SessionServerContextMixin(SessionCookieMixin, SessionBase):
         SessionBase.remove_session(self)
         if self.__sesid is not None:
             self.app.del_session(self.__sesid)
-            sesid = self.app.new_session()
-            self.__sesid = sesid
-            self._set_sesid_cookie(self.__sesid, self.app.ses_age())
+            self.__sesid = None
+            self._set_sesid_cookie(self.__sesid)
 
 
 class SessionServerAppMixin:
