@@ -1,4 +1,3 @@
-#
 # Copyright 2001 by Object Craft P/L, Melbourne, Australia.
 #
 # LICENCE - see LICENCE file distributed with this software for details.
@@ -52,6 +51,12 @@ class InputNameValueMixin:
         else:
             return name, ctx.get_value(name)
 
+    def input_add(self, ctx, itype, name, value, multiple):
+        if (not (self.has_attrib('disabledbool') 
+                 and self.eval_attrib(ctx, 'disabledbool')) 
+            and not self.has_attrib('disabled')):
+            ctx.input_add(itype, name, value, multiple)
+
 # ------------------------------------------------------------------
 
 # The HTML <INPUT> tag is wrapped so that variable values can be
@@ -129,8 +134,7 @@ class Input(EmptyTag, InputNameValueMixin):
                 ctx.write_content(' value="%s"' % value)
             else:
                 ctx.write_content(' value="%s"' % escape(value))
-        if not self.has_attrib('disabled'):
-            ctx.input_add(self.__itype, name, value, self.has_attrib('list'))
+        self.input_add(ctx, self.__itype, name, value, self.has_attrib('list'))
 
     def radio_to_html(self, ctx):
         self.write_attribs_except(ctx, 'value', 'checked')
@@ -139,8 +143,7 @@ class Input(EmptyTag, InputNameValueMixin):
         ctx.write_content(' value="%s"' % value_attr)
         if str(value) == str(value_attr):
             ctx.write_content(' checked')
-        if not self.has_attrib('disabled'):
-            ctx.input_add('radio', name, value_attr, self.has_attrib('list'))
+        self.input_add(ctx, 'radio', name, value_attr, self.has_attrib('list'))
 
     def checkbox_to_html(self, ctx):
         self.write_attribs_except(ctx, 'value', 'checked')
@@ -154,16 +157,14 @@ class Input(EmptyTag, InputNameValueMixin):
                 ctx.write_content(' checked')
         elif str(value) and str(value) == str(value_attr):
             ctx.write_content(' checked')
-        if not self.has_attrib('disabled'):
-            ctx.input_add('checkbox', name, value_attr, self.has_attrib('list'))
+        self.input_add(ctx, 'checkbox', name, value_attr, self.has_attrib('list'))
 
     def generic_novalue_to_html(self, ctx):
         # value= not applicable
         self.write_attribs_except(ctx, 'value')
         name = self.get_name(ctx)
         ctx.write_content(' name="%s"' % name)
-        if not self.has_attrib('disabled'):
-            ctx.input_add(self.__itype, name, None, self.has_attrib('list'))
+        self.input_add(ctx, self.__itype, name, None, self.has_attrib('list'))
 
     type_dict = {
         'text': generic_to_html, 'password': generic_to_html,
@@ -348,9 +349,8 @@ class Select(EnclosingTag, InputNameValueMixin):
             for item in self.options:
                 item.to_html(ctx, value)
         ctx.write_content('</select>')
-        if not self.has_attrib('disabled'):
-            ctx.input_add('select', name, None,
-                          self.has_attrib('list') or self.has_attrib('multiple'))
+        self.input_add(ctx, 'select', name, None, 
+                       self.has_attrib('list') or self.has_attrib('multiple'))
 
     def option_to_html(self, ctx, item, select_value):
         if type(item) is type(()):
@@ -407,8 +407,7 @@ class TextArea(EnclosingTag, InputNameValueMixin):
         else:
             EnclosingTag.to_html(self, ctx)
         ctx.write_content('</textarea>')
-        if not self.has_attrib('disabled'):
-            ctx.input_add('textarea', name, None, self.has_attrib('list'))
+        self.input_add(ctx, 'textarea', name, None, self.has_attrib('list'))
 
 
 # ------------------------------------------------------------------
